<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="unfinished">Entfernte Duplikate: </translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="unfinished">Es gibt Karten mit verschiedene Antworten für die Frage:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished">&amp;Zusammenfassen und bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="unfinished">&amp;Nicht zusammenfassen</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="unfinished">Fertig!</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Wie &apos;0&apos;, aber es beginnt vertrauter zu werden.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished"> Zeige sie weniger oft.</translation>
    </message>
    <message>
        <source>Error in config.py:</source>
        <translation type="unfinished">Fehler in config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="unfinished">Fehler beim Ausführen des Plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="unfinished">Konnte die Datei nicht laden.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="unfinished">Fasches Dateiformat.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="unfinished">Konnte die Datei nicht speichern.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="unfinished">Konnte XML nicht parsen:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="unfinished">Unbekannte Kodierung.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="unfinished">Fehlende Antwort in Zeile:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="unfinished">Konnte die Datenbank nicht laden.
Erstelle temporäre Datei.</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="unfinished">Vorhandene Datei:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="unfinished">&amp;Überschreiben</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Abbrechen</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Du kannst Dich noch nicht an diese Karte erinnern.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Du hast diese Karte jetzt gelernt,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"> und wirst sie für ein paar Tage behalten können.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Du hast diese Karte komplett vergessen.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Gerade noch richtige Antwort. Das Lernintervall war viel zu lang.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Richtige Anwort, aber mit viel Anstrengung.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"> Das Lernintervall war vermutlich zu lang.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Richtige Antwort, mit ein wenig Anstrengung.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished"> Das Lernintervall war wohl genau richtig.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Richtige Anwort, ganz ohne</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"> Schwierigkeiten. Das Lerninterwall war wahrscheinlich zu kurz.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Hauptautor: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">Mehr Informationen unter: http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Kategorien aktivieren</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Wähle die zu aktivierenden Kategorien:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Keine aktivieren</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Alle aktivieren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;Standard&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Aktuelle Karte abbrechen?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Schriftform:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Übersetzung:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Die Karte ist bereits in der Datenbank.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Duplikate wurden nicht hinzugefügt.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Es gibt verschiedene Antworten für</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> diese Frage:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Zusammenfassen und bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Unverändert hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Weglassen</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Karten hinzufügen</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Aussprache:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Auch ver&amp;tauscht hinzufügen</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+T</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Wähle die Anfangsbewertung:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Du kannst Dich nicht mehr an diese Einheit erinnern oder hast sie vergessen.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Wie &apos;0&apos;, aber es beginnt vertrauter zu werden.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Du hast diese Einheit jetzt gelernt und wirst sie für ein paar Tage behalten können.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Richtige Anwort, aber mit viel Anstrengung. Das Lernintervall war vermutlich zu lang</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Richtige Antwort, mit ein wenig Anstrengung. Das Lernintervall war genau richtig.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Richtige Anwort, ganz ohne Schwierigkeiten. Das Lernintervall war wohl zu kurz.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Schreibe die Frage und Antwort, dann wähle die Anfangsbewertung.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Vorschau</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Kategorie ändern</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemosyne einrichten</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Für weitergehende Informationen fahre mit der Maus über die Buttons.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>F/A Schrift einstellen</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Schriftgröße für die Anzeige der Fragen und Antworten einstellen</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Listenschrift einstellen</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Schriftgröße für die Auflistung aller Karten in einer Kartei einstellen</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Erhöhe die Schriftgröße für nicht-latin Zeichen um</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Manchmal sind Bildzeichen in der Standard Latin Schriftgröße schwer zu lesen</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>Punkt(e)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Upload des Logbuchs</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Upload von anonymisierten Logbüchern</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Gib anonyme Statistiken frei, um zur Lernforschung beizutragen</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Duplikate</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Auf Duplikate prüfen, wenn neue Karten hinzugefügt werden</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Erlaube Duplikate in verschiedenen Kategorien</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Lernprozess</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation>Kartenanzahl mit der Bewertung 0, die auf einmal gelernt werden:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Beachte: Das ist NICHT die Anzahl der mit 0 bewerteten Karten, die Du *pro Tag* lernen willst</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Standard wiederherstellen</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Karte bearbeiten</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Vorschau</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Vorschau</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>Ver&amp;tauscht hinzufügen</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>Statisti&amp;ken</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>Kategorie &amp;ändern</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Diese Karten vertauscht hinzufügen?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Diese Karte vertauscht hinzufügen?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Das kann Duplikate erzeugen, wenn die vertauschten </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>Karten bereits existieren.
Vielleicht möchtest Du </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>danach &apos;Duplikate aufräumen&apos; ausführen.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Bewertung:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Leichtigkeit:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Wiederholungen:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Tage seit der letzten Wiederholung:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Tage bis zur nächsten Wiederholung:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Diese Karten löschen?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Diese Karte löschen?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>Der eingegebene Text wurde nicht gefunden.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Weitersuchen</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Ver&amp;tauscht hinzufügen</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Antwort</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Kartei bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Zum Bearbeiten einer Karte, klicke mit der rechten Maustaste darauf.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle Dateien (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Datei exportieren</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Dateiformat:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Datei in die exportiert werden soll:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Durchsuchen</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Kategorien die exportiert werden sollen:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>Alles aus&amp;wählen</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Lerndaten beim Export zurücksetzen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;Standard&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle Dateien (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Datei importieren</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Dateiformat:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Datei die importiert werden soll:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Durchsuchen</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Karten ohne Kategorie verschieben nach:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Achtung: Alle Karten werden der aktuellen Datenbank hinzugefügt.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Lerndaten beim Import zurücksetzen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Mnemosyne Datenbanken (*.mem)</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>Aktuelle Karte löschen?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>Kommt wieder in </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation> Tag(en).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>Nächste Wiederholung: heute.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>Nächste Wiederholung: morgen.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>Nächste Wiederholung in </translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;Standard&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation>&amp;Antwort anzeigen</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>Ohne Rücksicht auf den Zeitplan weiterlernen</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>Wähle die Tage bis zur nächsten Wiederholung:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Bewerte deine Antwort:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>Vorgemerkt: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>Nicht gelernte: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation>Alle: </translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source> days.</source>
        <translation> Tage.</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Antwort anzeigen</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Bewerte deine Antwort:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Öffnen...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Karten hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>Karten &amp;hinzufügen</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Act&amp;ivate categories</source>
        <translation type="obsolete">Kategorien akt&amp;ivieren</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Kartei bearbeiten</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Kartei &amp;bearbeiten</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Import</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportieren</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Zeige &amp;Symbolleiste</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Aktuelle Karte bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Aktuelle Karte bearbeiten</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Aktuelle Karte löschen</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>Aktuelle Karte &amp;löschen</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Duplikate aufräumen</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>Mnemosyne &amp;einrichten</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Einführung</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Einführung</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Abwärts, Abwärts</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Zeige Statistiken</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Zeige Statisti&amp;ken</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Tipp des Tages</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Tipp des Tages</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Symbolleiste (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Kartei</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Kategorien akt&amp;ivieren</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;Standard&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Kartenvorschau</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Frage:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Einführung</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Sei gegrüßt!

Ich bin Mnemosyne, die griechische Muse der Erinnerung.

Das Erinnern und Lernen der Fragen und Antworten kann ich für Dich effizienter gestalten, indem ich Dir helfe Dich auf die Karteikarten zu konzentrieren, die Du am leichtesten vergisst und keine Zeit an diejenigen zu verschwenden, die Du schon kennst.

Darum werde ich entscheiden, wann ich dir die Frage stelle und du musst bewerten, wie gut du die Antwort behalten hast. 

Nun laß uns einmal die Bedeutung dieser Bewertungen ansehen.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Einführung</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Die Bewertungen reichen von 0 bis 5.

Die Bewertungen 0 und 1 werden vergeben, wenn Du die Antwort nicht weißt oder wenn Du sie vergessen hast. Eine Karte mit einer Bewertung von 1 beginnt Dir vertrauter zu werden als eine mit 0 und wird deswegen seltener wiederholt.

Bis Du eine Frage mit 2 oder besser bewertest (die exakte Bewertung spielt keine Rolle), werde ich fortfahren Dir die Frage zu stellen. Eine Bewertung von 2 bedeutet, daß Du meinst, auch nach ein oder zwei Tagen noch in der Lage zu sein die Karteikarte zu wissen. Das zeigt den Übergang vom Kurzzeitgedächtnis ins Langzeitgedächtnis an.

Ich werde die Karte dann für ein späteres Datum vormerken. Dabei gehe ich davon aus, daß Du dann immer noch in der Lage sein wirst, Dich mit ein wenig Anstrengung an die Antwort zu erinnern ohne sie ganz und gar vergessen zu haben. Das ist die effektivste Methode um zu lernen.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Bewertungen von 0 bis 2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Wenn ich Dir in Zukunft eine Frage zu früh stelle und Du kannst Dich leicht an die Antwort erinnern, dann bewerte die Karte mit einer 5. Ich werde das berücksichtigen, indem ich einige Zeit länger warte, bevor ich Dir diese Frage erneut stelle.

Treffe ich den Zeitpunkt genau richtig, so dass Du Dich, auch mit ein wenig Anstrengung, erinnern kannst, dann vergieb eine Bewertung von 4.

Andererseits, wenn Dich das Erinnern der Antwort sehr viel Mühe kostet und Du denkst, dass ich zu lange gewartet habe, bevor ich Dir diese Frage gestellt habe, dann bewerte die Karte mit einer 3.

Erinnerst Du Dich gar nicht mehr, dann vergieb eine 0 oder 1. Daraufhin werde ich Dir die Frage so lange weiterstellen, bis Du meinst, dass Du in der Lage bist, Dich in ein paar Tagen wieder zu erinnern.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Bewertungen von 3 bis 5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Hast Du die Statistiken aktiviert, werde ich genaue Aufzeichnungen über Deine Übungen führen.

Und nicht nur das. Wenn Du möchtest, kann ich eine komplett anonymisierte Version der Logbücher zur Analyse auf einen zentralen Server laden. Dadurch kannst Du mithelfen, mich besser zu machen und trägst gleichzeitig viel zur Forschung über das Langzeitlernen bei.

Wenn Du das nicht möchtest, dann deaktiviere die nachfolgende Checkbox.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Upload von anonymisierten Logbüchern</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Du kannst diese Einstellung jederzeit unter dem Menüeintrag &apos;Mnemosyne einrichten&apos; ändern.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see &lt;a href =&quot;http://mnemosyne-proj.sourceforge.net&quot;&gt;http://www.mnemosyne-proj.sourceforge.net&lt;/a&gt;
&lt;p&gt;
Happy learning!</source>
        <translation type="obsolete">Jetzt kannst Du anfangen!
&lt;p&gt;
Du kannst neue Fragen hinzufügen, indem du auf das &apos;Plus&apos; Symol links oben klickst.
&lt;p&gt;
Es ist im Übrigen nicht notwendig, daß Du Dir über das Abspeichern Deiner Übungen Gedanken machst. Das werde ich automatisch erledigen.
&lt;p&gt;
Für gute Ergebnisse schlage ich vor, daß Du Deine Übungen jeden Tag machst, auch wenn ich mein Bestes geben werde, wenn Du die Übungen aufschiebst oder aber voraus lernst.
&lt;p&gt;
Für weitergehende Informationen, besuche &lt;a href =&quot;http://mnemosyne-proj.sourceforge.net&quot;&gt;http://www.mnemosyne-proj.sourceforge.net&lt;/a&gt;
&lt;p&gt;
Viel Spass und Erfolg!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Startklar</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Jetzt kannst Du anfangen!
&lt;p&gt;
Du kannst neue Fragen hinzufügen, indem du auf das &apos;Plus&apos; Symbol links oben klickst.
&lt;p&gt;
Es ist im Übrigen nicht notwendig, daß Du Dir über das Abspeichern Deiner Übungen Gedanken machst. Das werde ich automatisch erledigen.
&lt;p&gt;
Für gute Ergebnisse schlage ich vor, daß Du Deine Übungen jeden Tag machst, auch wenn ich mein Bestes geben werde, wenn Du die Übungen aufschiebst oder aber voraus lernst.
&lt;p&gt;
Für weitergehende Informationen, besuche http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Viel Spass und Erfolg!</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>&amp;Bild einfügen</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>&amp;Musik einfügen</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;3-seitige Eingabe</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Bilddateien</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Bild einfügen</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Musikdateien</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Musik einfügen</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation>Vorgemerkte Karten für die nächsten Tage:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>In</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>Tag(en):</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Anzahl der Karten mit den folgenden Bewertungen:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Bewertung</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Karten</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Zeitplan</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Bewertungen</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorien</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>Für hervorragende Ergebnisse ist es am Besten, wenn Du Deine Übungen jeden Tag machst.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Wenn Du ein paar Tage nicht üben konntest, dann mach Dir keine Sorgen über Deinen Lernrückstand. Hole so viele Karten nach wie Du möchtest, die Restlichen werden automatisch neu eingeplant.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>Die Einstellung &apos;Kartenanzahl mit der Bewertung 0, die auf einmal gelernt werden&apos; legt fest, wieviele neue Karten Du zur selben Zeit versuchst zu lernen. Sie sagt &lt;b&gt;nichts&lt;/b&gt; darüber aus, wieviele neue Karten Du pro Tag lernen musst. Entscheide selbst: Du kannst mehr Karten oder auch weniger Karten lernen, ganz wie Du es willst.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Versuche im Großen und Ganzen Deine Übungen jeden Tag zu machen, aber sorge Dich nicht zu sehr, mit dem &apos;Vorgemerkt&apos; Zähler auf Null zu kommen und auf keinen Fall darüber den &apos;Nicht gelernte&apos; Zähler auf Null zu bringen.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Karten mit der Bewertung 1 unterscheiden sich von einer Karte mit 0 in der Weise, dass sie weniger oft angezeigt werden und sich in der Einstellung &apos;Kartenanzahl mit der Bewertung 0, die auf einmal gelernt werden&apos; nicht mehr auswirken.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Für Deine Übungen kannst Du Tastaturkürzel verwenden. Enter, Return oder Leertaste stehen für die Standardeingaben (&apos;Antwort anzeigen&apos; oder &apos;Bewertung 4&apos;). Die Nummerntasten können zum Bewerten benutzt werden.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Mit der Einstellung &apos;Kategorien aktivieren&apos; kannst Du festlegen, welche Kategorien Du lernen möchtest.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Es wird empfohlen, dass Du alle Karten in einer Datenbank speicherst und Kategorien zum Einordnen verwendest.  &apos;Kategorien aktivieren&apos; zu benutzen ist sehr viel bequemer als ständig verschiedene Datenbanken zu laden.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Du kannst Karten in vielen verschiedenen Formaten importieren: Tab getrennte txt Dateien, Supermemo Dateien, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Wenn Du Karten in Word oder Excel hast, dann exportiere diese in Tab getrennte txt Dateien mit UTF-8 Unicode Kodierung, damit Du sie in Mnemosyne importieren kannst.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Wenn Du Deine Karten drucken möchtest, dann exportiere sie einfach in eine txt Datei. Diese kannst Du dann in Deiner Textverarbeitung öffnen und drucken.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Du kannst Deine Karten mit anderen teilen, wenn Du sie in das XML format exportierst und die Einstellung &apos;Lerndaten beim Export zurücksetzen&apos; beim Exportieren auswählst.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Wenn Du eine ausländische Sprache mit eigener Schrift lernst, ist die Schriftgröße manchmal ein wenig klein. Willst Du die Größe dieser Buchstaben erhöhen, aber die Größe für deutschen Text beibehalten, dann verwende die &apos;Erhöhe die Schriftgröße für nicht-latin Zeichen um X Punkt(e)&apos; Einstellung.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Zu Deine Karten kannst Du Bilder und Musik hinzufügen. Ein &apos;Rechtsklick&apos; im Frage- oder Antwortfeld beim Bearbeiten einer Karte öffnet ein entsprechendes Pop-Up Menü.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Es wird empfohlen, dass Du Bild- und Musikdateien in Deinem .mnemosyne Verzeichnis ablegst. Das macht es einfacher die Daten zwischen verschiedenen Computern hin und her zu übertragen.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Beim Hinzufügen einer dreiseitigen Karte werden zwei normale Karten erstellt. Eine mit der Schriftform als Frage und der Aussprache und Übersetzung als Antwort. Eine weitere mit der Übersetzung als Frage und der Schriftform und Aussprache als Antwort.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Um das Erscheinungsbild anzupassen, kannst Du einfache HTML Tags in Deinen Karten verwenden.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne kann LaTeX verwenden um mathematische Formeln, wie z.B. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt; anzuzeigen. (Dafür muss aber LaTeX und dvipng installiert sein.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>Der beste Weg um eine Sicherung Deiner Daten zu erstellen, ist Dein .mnemosyne Verzeichnis auf ein anderes Laufwerk zu kopieren (Wenn Du der Empfehlung folgst, alle Deine Dateien dort abzulegen). Mnemosyne bewahrt XML basierte Sicherungen automatisch in .mnemosyne/backups auf, aber das wird Dir nicht helfen, wenn Deine Festplatte kaputt geht... </translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Wenn Du Mnemosyne auf mehreren Computern benutzt, dann gibt es eine praktische Hilfe mit dem Namen Unison um Dir zu helfen Deine Daten zu synchronisieren. Besuche die Mnemosyne Webseite für mehr Informationen hierzu.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Du kannst die Karten im &apos;Kartei bearbeiten&apos; Dialog nach Antworten oder Kategorien sortieren, wenn Du auf den entsprechenden Spaltentitel klickst. Erneutes klicken ändert die Sortierreihenfolge.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Erfahrene Benutzer können Mnemosyne noch besser konfigurieren, indem sie die Datei config.py in ihrem .mnemosyne Verzeichnis bearbeiten. Sie können auch Plugins installieren, um Mnemosyne noch weiter an ihre Bedürfnisse anzupassen.</translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Du kannst Mnemosyne von einem USB Stick aus ausführen. Kopiere dazu C:\Programme\Mnemosyne auf den USB Stick und kopiere dann das .mnemosyne Verzeichnis von Deinem Heimverzeichnis in das Mnemosyne Verzeichnis auf Deinem USB Stick.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Möchtest Du eine genauere Kontrolle über das LaTeX Verhalten, dann lies die Erklärung zu den &lt;$$&gt;...&lt;/$$&gt; und &lt;latex&gt;...&lt;/latex&gt; Tags auf der Mnemosyne Webseite.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Tipp des Tages</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wußtest Du, dass...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Zeige Tipps beim Start</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Vorheriger</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Weiter</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>qApp</name>
    <message>
        <source>Error in config.py:</source>
        <translation type="obsolete">Fehler in config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="obsolete">Fehler beim Ausführen des Plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="obsolete">Konnte die Datei nicht laden.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="obsolete">Fasches Dateiformat.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="obsolete">Konnte die Datei nicht speichern.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="obsolete">Konnte XML nicht parsen:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="obsolete">Unbekannte Kodierung.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="obsolete">Fehlende Antwort in Zeile:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="obsolete">Konnte die Datenbank nicht laden.
Erstelle temporäre Datei.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="obsolete">Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="obsolete">Vorhandene Datei:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="obsolete">&amp;Überschreiben</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="obsolete">Entfernte Duplikate: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="obsolete">Es gibt Karten mit verschiedene Antworten für die Frage:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="obsolete">&amp;Zusammenfassen und bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="obsolete">&amp;Nicht zusammenfassen</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="obsolete">Fertig!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="obsolete">Du kannst Dich noch nicht an diese Karte erinnern.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="obsolete">Wie &apos;0&apos;, aber es beginnt vertrauter zu werden.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="obsolete"> Zeige sie weniger oft.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="obsolete">Du hast diese Karte jetzt gelernt,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="obsolete"> und wirst sie für ein paar Tage behalten können.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="obsolete">Du hast diese Karte komplett vergessen.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="obsolete">Gerade noch richtige Antwort. Das Lernintervall war viel zu lang.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="obsolete">Richtige Anwort, aber mit viel Anstrengung.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="obsolete"> Das Lernintervall war vermutlich zu lang.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="obsolete">Richtige Antwort, mit ein wenig Anstrengung.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="obsolete"> Das Lernintervall war wohl genau richtig.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="obsolete">Richtige Anwort, ganz ohne</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="obsolete"> Schwierigkeiten. Das Lerninterwall war wahrscheinlich zu kurz.</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="obsolete"> Tage.</translation>
    </message>
</context>
</TS>
